@@ -1,34 +1,18 @@
 package Class::Null;
-
+use 5.006;
 use warnings;
 use strict;
-
-our $VERSION = '1.10';
-
+our $VERSION = '1.11';
 use overload
-    'bool'   => sub { 0 },
-    '""'     => sub { '' },
-    '0+'     => sub { 0 },
-    fallback => 1;
-
-sub new {
-    # the following simple line doesn't work... :(
-    # our $singleton ||= bless {}, shift
-
-    our $singleton;
-    return $singleton if defined $singleton;
-    $singleton = bless {}, shift
-}
-
-sub AUTOLOAD { our $singleton }
-
-
+  'bool'   => sub { 0 },
+  '""'     => sub { '' },
+  '0+'     => sub { 0 },
+  fallback => 1;
+our $null = bless {}, __PACKAGE__;
+sub AUTOLOAD { $null }
 1;
-
 __END__
 
-
-
 =head1 NAME
 
 Class::Null - Implements the Null Class design pattern
@@ -41,17 +25,17 @@ Class::Null - Implements the Null Class design pattern
 
   sub init {
     my $self = shift;
-    ...
+    # ...
     $self->log(Class::Null->new);
-    ...
+    # ...
   }
 
   sub do_it {
     my $self = shift;
     $self->log->log(level => 'debug', message => 'starting to do it');
-    ...
+    # ...
     $self->log->log(level => 'debug', message => 'still doing it');
-    ...
+    # ...
     $self->log->log(level => 'debug', message => 'finished doing it');
   }
 
@@ -79,7 +63,7 @@ can be accessed using an accessor method:
 
 The log object simply needs to have a C<log()> method that accepts
 two named parameters. Any class defining such a method will do, and
-C<Log::Dispatch> fulfils that requirement while providing a lot of
+C<Log::Dispatch> fulfills that requirement while providing a lot of
 flexibility and reusability in handling the logged messages.
 
 You might want to log messages to a file:
@@ -164,11 +148,11 @@ definitions.
 
 =over 4
 
-=item new()
+=item C<new()>
 
 Returns the singleton null object.
 
-=item any other method
+=item C<any other method>
 
 Returns another singleton null object so method chaining works.
 
@@ -207,7 +191,7 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/Class-Null/>.
 
 =head1 AUTHORS
 
@@ -215,11 +199,9 @@ Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2005-2008 by the authors.
+Copyright 2005-2009 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
 =cut
-
